@@ -159,7 +159,13 @@ anjuta_preferences_dialog_init (AnjutaPreferencesDialog *dlg)
 	
 	dlg->priv = g_new0 (AnjutaPreferencesDialogPrivate, 1);
 
-	hbox = gtk_hbox_new (FALSE, 0);	
+	gtk_container_set_border_width (GTK_CONTAINER(dlg), 6);
+
+	hbox = g_object_new(GTK_TYPE_HBOX,
+	                    "border-width", 6,
+	                    "spacing", 6,
+	                    "visible", TRUE,
+	                    NULL);
 	
 	dlg->priv->treeview = gtk_tree_view_new ();
 	gtk_widget_show (dlg->priv->treeview);
@@ -185,7 +191,7 @@ anjuta_preferences_dialog_init (AnjutaPreferencesDialog *dlg)
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-					GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+					GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type 
 		(GTK_SCROLLED_WINDOW (scrolled_window), GTK_SHADOW_IN);
 	
@@ -200,8 +206,6 @@ anjuta_preferences_dialog_init (AnjutaPreferencesDialog *dlg)
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (dlg->priv->notebook), FALSE);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (dlg->priv->notebook), 
 				      FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dlg->priv->notebook),
-					8);
 	
 	gtk_box_pack_start (GTK_BOX (hbox), dlg->priv->notebook,
 			    TRUE, TRUE, 0);
