@@ -46,6 +46,7 @@ typedef enum
 
 struct _AnjutaProjectProperty
 {
+	gchar *id;
 	gchar *name;
 	AnjutaProjectValueType type;
 	AnjutaProjectPropertyFlags flags;
@@ -56,7 +57,7 @@ struct _AnjutaProjectProperty
 
 GType anjuta_project_property_get_type (void);
 
-AnjutaProjectProperty *anjuta_project_property_new (const gchar *name, AnjutaProjectValueType type, const gchar *value, AnjutaProjectProperty *native);
+AnjutaProjectProperty *anjuta_project_property_new (const gchar *id, const gchar *name, AnjutaProjectValueType type, const gchar *value, AnjutaProjectProperty *native);
 AnjutaProjectProperty * anjuta_project_property_copy (AnjutaProjectProperty *prop);
 void anjuta_project_property_free (AnjutaProjectProperty *prop);
 
@@ -138,6 +139,7 @@ struct _AnjutaProjectNode
 {
 	GInitiallyUnowned parent_instance;
 
+	/*< private >*/
 	AnjutaProjectNode	*next;
 	AnjutaProjectNode *prev;
 	AnjutaProjectNode	*parent;
@@ -163,6 +165,10 @@ struct _AnjutaProjectNodeClass
 
 
 typedef gboolean (*AnjutaProjectNodeTraverseFunc) (AnjutaProjectNode *node, gpointer data);
+/**
+ * AnjutaProjectNodeForeachFunc:
+ * @data: (closure):
+ */
 typedef void (*AnjutaProjectNodeForeachFunc) (AnjutaProjectNode *node, gpointer data);
 
 
@@ -208,9 +214,9 @@ gboolean anjuta_project_node_clear_state (AnjutaProjectNode *node, AnjutaProject
 AnjutaProjectProperty *anjuta_project_node_insert_property (AnjutaProjectNode *node, AnjutaProjectProperty *native, AnjutaProjectProperty *property);
 AnjutaProjectProperty *anjuta_project_node_remove_property (AnjutaProjectNode *node, AnjutaProjectProperty *property);
 
-AnjutaProjectNode *anjuta_project_group_get_node_from_file (const AnjutaProjectNode *root, GFile *directory);
+AnjutaProjectNode *anjuta_project_node_get_group_from_file (const AnjutaProjectNode *root, GFile *directory);
 AnjutaProjectNode *anjuta_project_target_get_node_from_name (const AnjutaProjectNode *parent, const gchar *name);
-AnjutaProjectNode *anjuta_project_source_get_node_from_file (const AnjutaProjectNode *parent, GFile *file);
+AnjutaProjectNode *anjuta_project_node_get_source_from_file (const AnjutaProjectNode *parent, GFile *file);
 
 
 
