@@ -170,7 +170,7 @@ project_load_group_module (AmpProject *project, AmpGroupNode *group)
 								/* Add new module */
 								AnjutaProjectNode *new_module;
 
-								new_module = amp_node_new (target, ANJUTA_PROJECT_MODULE, NULL, name, NULL);
+								new_module = amp_node_new_valid (target, ANJUTA_PROJECT_MODULE, NULL, name, NULL);
 								anjuta_project_node_append (target, new_module);
 							}
 							g_free (cpp_flags);
@@ -281,6 +281,17 @@ amp_group_node_add_token (AmpGroupNode *group, AnjutaToken *token, AmpGroupNodeT
 	group->tokens[category] = g_list_prepend (group->tokens[category], token);
 }
 
+void
+amp_group_node_remove_token (AmpGroupNode *group, AnjutaToken *token)
+{
+	gint i;
+
+	for (i = 0; i < AM_GROUP_TOKEN_LAST; i++)
+	{
+		group->tokens[i] = g_list_remove (group->tokens[i], token);
+	}
+}
+
 GList *
 amp_group_node_get_token (AmpGroupNode *group, AmpGroupNodeTokenCategory category)
 {
@@ -477,8 +488,7 @@ amp_group_node_update_variable (AmpGroupNode *group, AnjutaToken *variable)
 
 	arg = anjuta_token_first_item (variable);
 	name = g_strstrip (anjuta_token_evaluate (arg));
-	arg = anjuta_token_next_item (arg);
-	value = anjuta_token_next_item (arg);
+	value = anjuta_token_last_item (variable);
 
 	var = (AmpVariable *)g_hash_table_lookup (group->variables, name);
 	if (var != NULL)
@@ -498,22 +508,24 @@ AnjutaToken*
 amp_group_node_get_variable_token (AmpGroupNode *group, AnjutaToken *variable)
 {
 	guint length;
-	const gchar *string;
-	gchar *name;
+	gchar *string;
+	const gchar *name;
 	AmpVariable *var;
 		
-	length = anjuta_token_get_length (variable);
-	string = anjuta_token_get_string (variable);
+	string = anjuta_token_evaluate(variable);
+	length = strlen (string);
 	if (string[1] == '(')
 	{
-		name = g_strndup (string + 2, length - 3);
+		string[length - 1] = '\0';
+		name = string + 2;
 	}
 	else
 	{
-		name = g_strndup (string + 1, 1);
+		string[2] = '\0';
+		name = string + 1;
 	}
 	var = g_hash_table_lookup (group->variables, name);
-	g_free (name);
+	g_free (string);
 
 	return var != NULL ? var->value : NULL;
 }
@@ -528,9 +540,21 @@ amp_group_node_set_file (AmpGroupNode *group, GFile *new_file)
 }
 
 AmpGroupNode*
-amp_group_node_new (GFile *file, gboolean dist_only, GError **error)
+amp_group_node_new (GFile *file, gboolean dist_only)
 {
 	AmpGroupNode *node = NULL;
+	
+	node = g_object_new (AMP_TYPE_GROUP_NODE, NULL);
+	node->base.file = g_object_ref (file);
+	node->dist_only = dist_only;
+	memset (node->tokens, 0, sizeof (node->tokens));
+
+    return node;	
+}
+
+AmpGroupNode* 
+amp_group_node_new_valid (GFile *file, gboolean dist_only, GError **error)
+{
 	gchar *name;
 
 	/* Validate group name */
@@ -558,13 +582,8 @@ amp_group_node_new (GFile *file, gboolean dist_only, GError **error)
 		}
 	}
 	g_free (name);
-	
-	node = g_object_new (AMP_TYPE_GROUP_NODE, NULL);
-	node->base.file = g_object_ref (file);
-	node->dist_only = dist_only;
-	memset (node->tokens, 0, sizeof (node->tokens));
 
-    return node;	
+	return amp_group_node_new (file, dist_only);
 }
 
 void
