@@ -22,7 +22,11 @@
 
 #include "message-view.h"
 #define MESSAGE_TYPE message_get_type()
-	
+
+#define PREFERENCES_SCHEMA "org.gnome.anjuta.message-manager"
+#define COLOR_ERROR "msgman-color-error"
+#define COLOR_WARNING "msgman-color-warning"
+
 struct _MessageViewPrivate
 {
 	//guint num_messages;
@@ -48,8 +52,7 @@ struct _MessageViewPrivate
 	gchar *pixmap;
 	gboolean highlite;
 	
-	/* gconf notification ids */
-	GList *notify_ids;
+	GSettings* settings;
 };
 
 typedef struct
@@ -282,8 +285,8 @@ on_message_event (GObject* object, GdkEvent* event, gpointer data)
 	{
 		switch(((GdkEventKey *)event)->keyval)
 		{
-			case GDK_space:
-			case GDK_Return:
+			case GDK_KEY_space:
+			case GDK_KEY_Return:
 			{
 				const gchar* message =
 					ianjuta_message_view_get_current_message(IANJUTA_MESSAGE_VIEW (view), NULL);
@@ -432,11 +435,7 @@ static void
 message_view_dispose (GObject *obj)
 {
 	MessageView *mview = MESSAGE_VIEW (obj);
-	if (mview->privat->notify_ids)
-	{
-		prefs_finalize (mview);
-		mview->privat->notify_ids = NULL;
-	}
+	prefs_finalize (mview);
 	if (mview->privat->tree_view)
 	{
 		mview->privat->tree_view = NULL;
@@ -610,6 +609,8 @@ message_view_serialize (MessageView *view, AnjutaSerializer *serializer)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
+
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
 	
 	if (!anjuta_serializer_write_string (serializer, "label",
 										 view->privat->label))
@@ -650,6 +651,8 @@ message_view_deserialize (MessageView *view, AnjutaSerializer *serializer)
 {
 	GtkTreeModel *model;
 	gint messages, i;
+
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
 	
 	if (!anjuta_serializer_read_string (serializer, "label",
 										&view->privat->label, TRUE))
@@ -691,6 +694,8 @@ void message_view_next(MessageView* view)
 	GtkTreeModel *model;
 	GtkTreeSelection *select;
 
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
+	
 	model = view->privat->model;
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW
 					      (view->privat->tree_view));
@@ -735,6 +740,8 @@ void message_view_previous(MessageView* view)
 	GtkTreeSelection *select;
 	GtkTreePath *path;
 
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
+	
 	model = view->privat->model;
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW
 					      (view->privat->tree_view));
@@ -787,7 +794,10 @@ static gboolean message_view_save_as(MessageView* view, gchar* uri)
 	GtkTreeModel *model;
 	gboolean ok;
 
-	if (uri == NULL) return FALSE;
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
+	
+	if (uri == NULL) 
+		return FALSE;
 
 	file = g_file_new_for_uri (uri);
 	os = G_OUTPUT_STREAM (
@@ -846,8 +856,10 @@ void message_view_save(MessageView* view)
 {
 	GtkWindow* parent;
 	gchar* uri;
-     
-       	parent = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (view)));	
+
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
+
+	parent = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (view)));	
 
 	uri = ask_user_for_save_uri (parent);
 	if (uri)
@@ -866,6 +878,8 @@ void message_view_copy(MessageView* view)
 	GtkTreeModel *model;
 	GtkTreeSelection *select;
 
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
+	
 	model = view->privat->model;
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW
 					      (view->privat->tree_view));
@@ -908,7 +922,7 @@ pref_change_color (MessageView *mview, IAnjutaMessageViewType type,
 	GtkTreeIter iter;
 	gboolean success;
 	
-	color = anjuta_preferences_get (anjuta_preferences_default(), color_pref_key);
+	color = g_settings_get_string (mview->privat->settings, color_pref_key);
 	store = GTK_LIST_STORE (mview->privat->model);
 	success = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
 	while (success)
@@ -927,47 +941,35 @@ pref_change_color (MessageView *mview, IAnjutaMessageViewType type,
 
 
 static void
-on_notify_color (AnjutaPreferences* prefs, const gchar* key,
-                 const gchar* value, gpointer user_data)
+on_notify_color (GSettings* settings, const gchar* key,
+                 gpointer user_data)
 {
-	pref_change_color (MESSAGE_VIEW (user_data),
-					   IANJUTA_MESSAGE_VIEW_TYPE_WARNING,
-					   key);
+	if (g_str_equal (key, COLOR_ERROR))
+	    pref_change_color (MESSAGE_VIEW (user_data),
+	                       IANJUTA_MESSAGE_VIEW_TYPE_ERROR,
+	                       key);
+	else
+	    pref_change_color (MESSAGE_VIEW (user_data),
+	                       IANJUTA_MESSAGE_VIEW_TYPE_WARNING,
+	                       key);
 }
 
 static void
 prefs_init (MessageView *mview)
 {
-	gint id;
-	id = anjuta_preferences_notify_add_string (anjuta_preferences_default (),
-	                                           "messages.color.error",
-	                                           on_notify_color,
-	                                           mview,
-	                                           NULL);
-	mview->privat->notify_ids = g_list_append (mview->privat->notify_ids,
-	                                           GINT_TO_POINTER (id));	
-	id = anjuta_preferences_notify_add_string (anjuta_preferences_default (),
-	                                      "messages.color.warning",
-	                                      on_notify_color,
-	                                      mview,
-	                                      NULL);
-	mview->privat->notify_ids = g_list_append (mview->privat->notify_ids,
-	                                         GINT_TO_POINTER (id));
+	mview->privat->settings = g_settings_new (PREFERENCES_SCHEMA);
+	g_signal_connect (mview->privat->settings, "changed::" COLOR_ERROR,
+	                  G_CALLBACK (on_notify_color), mview);
+	g_signal_connect (mview->privat->settings, "changed::" COLOR_WARNING,
+	                  G_CALLBACK (on_notify_color), mview);
 }
 
 static void
 prefs_finalize (MessageView *mview)
 {
-	GList *node;
-	node = mview->privat->notify_ids;
-	while (node)
-	{
-		anjuta_preferences_notify_remove (anjuta_preferences_default(),
-										  GPOINTER_TO_INT (node->data));
-		node = g_list_next (node);
-	}
-	g_list_free (mview->privat->notify_ids);
-	mview->privat->notify_ids = NULL;
+	if (mview->privat->settings)
+		g_object_unref (mview->privat->settings);
+	mview->privat->settings = NULL;
 }
 
 /* IAnjutaMessageView interface implementation */
@@ -1041,15 +1043,13 @@ imessage_view_append (IAnjutaMessageView *message_view,
 				stock_id = GTK_STOCK_INFO;
 				break;
 			case IANJUTA_MESSAGE_VIEW_TYPE_WARNING:
-				color = anjuta_preferences_get (anjuta_preferences_default(),
-									  "messages.color.warning");
+				color = g_settings_get_string (view->privat->settings, COLOR_WARNING);
 				/* FIXME: There is no GTK_STOCK_WARNING which would fit better here */
 				view->privat->warn_count++;
 				stock_id = GTK_STOCK_DIALOG_WARNING;
 				break;
 			case IANJUTA_MESSAGE_VIEW_TYPE_ERROR:
-				color = anjuta_preferences_get (anjuta_preferences_default(),
-									  "messages.color.error");
+				color = g_settings_get_string (view->privat->settings, COLOR_ERROR);
 				view->privat->error_count++;
 				stock_id = GTK_STOCK_STOP;
 				break;
@@ -1256,17 +1256,23 @@ message_view_tree_view_filter (GtkTreeModel *model, GtkTreeIter  *iter,
 MessageViewFlags
 message_view_get_flags (MessageView* view)
 {
+	g_return_val_if_fail (view != NULL && MESSAGE_IS_VIEW (view), MESSAGE_VIEW_SHOW_NORMAL);
+
 	return view->privat->flags;
 }
 
 void message_view_set_flags (MessageView* view, MessageViewFlags flags)
 {
+	g_return_if_fail (view != NULL && MESSAGE_IS_VIEW (view));
+	                  
 	view->privat->flags = flags;
 	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER(view->privat->filter));
 }
 
 gint message_view_get_count (MessageView* view, MessageViewFlags flags)
 {
+	g_return_val_if_fail (view != NULL && MESSAGE_IS_VIEW (view), 0);
+	
 	switch (flags)
 	{
 		case MESSAGE_VIEW_SHOW_NORMAL:
@@ -1284,4 +1290,4 @@ gint message_view_get_count (MessageView* view, MessageViewFlags flags)
 
 ANJUTA_TYPE_BEGIN(MessageView, message_view, GTK_TYPE_HBOX);
 ANJUTA_TYPE_ADD_INTERFACE(imessage_view, IANJUTA_TYPE_MESSAGE_VIEW);
-ANJUTA_TYPE_END;
+ANJUTA_TYPE_END;
\ No newline at end of file
