@@ -440,17 +440,17 @@ on_new_group (GtkAction *action, ProjectManagerPlugin *plugin)
 	
 	if (plugin->current_editor_uri)
 	{
-		gchar *path = g_path_get_dirname (plugin->current_editor_uri);
-		default_group = g_file_new_for_path (path);
-		g_free (path);
+		gchar *uri = g_path_get_dirname (plugin->current_editor_uri);
+		default_group = g_file_new_for_uri (uri);
+		g_free (uri);
 	}
 	
 	group =
 		ianjuta_project_manager_add_group (IANJUTA_PROJECT_MANAGER (plugin),
 										   "", default_group,
 										   NULL);
-	g_object_unref (group);
-	g_object_unref (default_group);
+	if (group != NULL) g_object_unref (group);
+	if (default_group != NULL) g_object_unref (default_group);
 }
 
 static void
@@ -495,17 +495,18 @@ on_new_target (GtkAction *action, ProjectManagerPlugin *plugin)
 	
 	if (plugin->current_editor_uri)
 	{
-		gchar *path = g_path_get_dirname (plugin->current_editor_uri);
-		default_group = g_file_new_for_path (path);
-		g_free (path);
+		gchar *uri = g_path_get_dirname (plugin->current_editor_uri);
+		default_group = g_file_new_for_uri (uri);
+		g_free (uri);
 	}
 	
 	target =
 		ianjuta_project_manager_add_target (IANJUTA_PROJECT_MANAGER (plugin),
 											"", default_group,
 											NULL);
-	g_object_unref (target);
-	g_object_unref (default_group);
+
+	if (target != NULL) g_object_unref (target);
+	if (default_group != NULL) g_object_unref (default_group);
 }
 
 static void
@@ -517,17 +518,18 @@ on_add_source (GtkAction *action, ProjectManagerPlugin *plugin)
 	
 	if (plugin->current_editor_uri)
 	{
-		gchar *path = g_path_get_dirname (plugin->current_editor_uri);
-		default_group = g_file_new_for_path (path);
-		g_free (path);
+		gchar *uri = g_path_get_dirname (plugin->current_editor_uri);
+		default_group = g_file_new_for_uri (uri);
+		g_free (uri);
 		source_uri = plugin->current_editor_uri;
 	}
 	source =
 		ianjuta_project_manager_add_source (IANJUTA_PROJECT_MANAGER (plugin),
 											source_uri,
 											default_group, NULL);
-	g_object_unref (source);
-	g_object_unref (default_group);
+
+	if (source != NULL) g_object_unref (source);
+	if (default_group != NULL) g_object_unref (default_group);
 }
 
 static void
@@ -1765,6 +1767,12 @@ file_is_inside_project (ProjectManagerPlugin *plugin, GFile *file)
 {
 	gchar *uri = g_file_get_uri (file);
 	gboolean inside = FALSE;
+
+	if (plugin->project_root_uri == NULL)
+	{
+		/* No project open */
+		return FALSE;
+	}
 	
 	if (strncmp (uri, plugin->project_root_uri,
 				 strlen (plugin->project_root_uri)) == 0)
@@ -1925,11 +1933,9 @@ iproject_manager_get_target_type (IAnjutaProjectManager *project_manager,
 						  ANJUTA_PROJECT_UNKNOWN);
 	
 	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (G_OBJECT (project_manager));
-	
-	g_return_val_if_fail (file_is_inside_project (plugin, target_file),
-						  ANJUTA_PROJECT_UNKNOWN);
 
-	if (plugin->project !=  NULL)
+	/* Check that file belongs to the project */
+	if ((plugin->project != NULL) && file_is_inside_project (plugin, target_file))
 	{
 		AnjutaProjectNode *node;
 
@@ -1987,7 +1993,11 @@ iproject_manager_get_parent (IAnjutaProjectManager *project_manager,
 		{
 			node = get_node_from_file (node, element);
 			if (node != NULL) node = anjuta_project_node_parent (node);
-			if (node != NULL) file = g_object_ref (anjuta_project_node_get_file (node));
+			if (node != NULL)
+			{
+				file = anjuta_project_node_get_file (node);
+				if (file != NULL) g_object_ref (file);
+			}
 		}
 	}
 
