@@ -58,6 +58,7 @@ struct _NPWProperty {
 	NPWPropertyType type;
 	NPWPropertyType restriction;
 	NPWPropertyOptions options;
+	gdouble range[3];
 	gchar* label;
 	gchar* description;
 	gchar* defvalue;
@@ -329,19 +330,11 @@ npw_property_get_description (const NPWProperty* prop)
 	return prop->language == 0 ? _(prop->description) : prop->description;
 }
 
-static void
-cb_boolean_button_toggled (GtkButton *button, gpointer data)
-{
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
-		gtk_button_set_label (button, _("Yes"));
-	else
-		gtk_button_set_label (button, _("No"));
-}
-
 static void
 cb_browse_button_clicked (GtkButton *button, NPWProperty* prop)
 {
 	GtkWidget *dialog;
+	gchar *path;
 	
 	switch (prop->type)
 	{
@@ -352,6 +345,15 @@ cb_browse_button_clicked (GtkButton *button, NPWProperty* prop)
 												 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				      							 GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 				      							 NULL);
+		path = g_strdup(gtk_entry_get_text(GTK_ENTRY(prop->widget)));
+		while (g_file_test(path, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR) == FALSE)
+		{
+			char* tmp = g_path_get_dirname(path);
+			g_free(path);
+			path = tmp;
+		}
+		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), path);
+		g_free(path);
 		break;
 	case NPW_FILE_PROPERTY:
 		dialog = gtk_file_chooser_dialog_new (_("Select file"),
@@ -446,17 +448,17 @@ npw_property_create_widget (NPWProperty* prop)
 	switch (prop->type)
 	{
 	case NPW_BOOLEAN_PROPERTY:
-		entry = gtk_toggle_button_new_with_label (_("No"));
-		g_signal_connect (G_OBJECT (entry), "toggled",
-						  G_CALLBACK (cb_boolean_button_toggled), NULL);
+		entry = gtk_switch_new ();
 		if (value)
 		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (entry),
-										  (gboolean)atoi (value));
+			gtk_switch_set_active (GTK_SWITCH (entry),
+			                      (gboolean)atoi (value));
 		}
 		break;
 	case NPW_INTEGER_PROPERTY:
-		entry = gtk_spin_button_new (NULL, 1, 0);
+		if (prop->range[1] == 0) prop->range[1] = 10000;
+		if (prop->range[2] == 0) prop->range[2] = 1;
+		entry = gtk_spin_button_new_with_range (prop->range[0], prop->range[1], prop->range[2]);
 		if (value)
 		{
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (entry), atoi (value));
@@ -621,6 +623,20 @@ npw_property_set_default (NPWProperty* prop, const gchar* value)
 	}
 }
 
+gboolean
+npw_property_set_range (NPWProperty* prop, NPWPropertyRangeMark mark, const gchar* value)
+{
+	char *end;
+	double d;
+	gboolean ok;
+
+	d = strtod (value,  &end);
+	ok = (*end == ':')  || (*end == '\0');
+	if (ok) prop->range[mark] = d;
+
+	return ok;
+}
+
 static gboolean
 npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 {
@@ -638,7 +654,7 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 		value = alloc_value;
 		break;
 	case NPW_BOOLEAN_PROPERTY:
-		alloc_value = g_strdup_printf("%d", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prop->widget)));
+		alloc_value = g_strdup_printf("%d", gtk_switch_get_active (GTK_SWITCH (prop->widget)));
 		value = alloc_value;
 		break;
 	case NPW_STRING_PROPERTY:
@@ -692,8 +708,11 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 			else
 				str_value = g_string_new (node->data);
 		}
-		value = str_value->str;
-		g_string_free (str_value, FALSE);
+		if (str_value != NULL)
+		{
+			value = str_value->str;
+			g_string_free (str_value, FALSE);
+		}
 		g_list_foreach (packages, (GFunc) g_free, NULL);
 		g_list_free (packages);	
 		break;
