@@ -240,13 +240,11 @@ on_save_finished (GObject* file, GAsyncResult* result, gpointer data)
 	SourceviewIO* sio = SOURCEVIEW_IO(data);
 	AnjutaShell* shell = ANJUTA_PLUGIN (sio->sv->priv->plugin)->shell;
 	GError* err = NULL;
-	gchar* etag = NULL;
 	g_file_replace_contents_finish (G_FILE (file),
 	                                result,
-	                                &etag,
+	                                NULL,
 	                                &err);
 	g_free (sio->write_buffer);
-	g_free (etag);
 	sio->write_buffer = NULL;
 	if (err)
 	{
